@@ -53,4 +53,10 @@ enum UserRoles {
     UserRoleSaveTimestamp,
 };
 
+#ifdef Q_WS_MAEMO_5
+#define TRACKER_PATH "/home/user/.config/tracker/tracker.cfg"
+#else
+#define TRACKER_PATH "/tmp/tracker.cfg"
+#endif
+
 #endif /* CONFIG_H */
