@@ -19,11 +19,9 @@ public:
 private:
     Ui::FindIpkWindow *ui;
     GameInfo * _game;
-    bool _urlLaunched;
 
 private slots:
     void on_locateButton_clicked();
-    void on_urlButton_clicked();
 };
 
 #endif // FINDIPKWINDOW_H
