@@ -203,10 +203,16 @@ bool InstallWindow::Step4Unpack()
     ui->animationLabel->show();
     _movie.start();
 
-    _proc1.setStandardOutputProcess(&_proc2);
-    _proc1.start("ar p \"" + _game->IPKPath() + "\" data.tar.gz");
-    _proc2.start(TAR_APP" xz -C \"" + _game->DataPath() + "\"");
-    connect(&_proc2, SIGNAL(finished(int)), this, SLOT(Step4Finished()));
+    _proc1.close();
+    QStringList env = QProcess::systemEnvironment();
+    env << "PATH=/usr/bin/gnu:$PATH";
+    env.replaceInStrings(QRegExp("^PATH=(.*)", Qt::CaseInsensitive), "PATH=/usr/bin/gnu:$PATH");
+    _proc1.setEnvironment(env);
+
+    _proc1.start("/usr/bin/dpkg-deb -X \"" + 
+                 _game->IPKPath() + "\" \"" +
+		 _game->DataPath() + "\"");
+    connect(&_proc1, SIGNAL(finished(int)), this, SLOT(Step4Finished()));
 
     return true;
 }
@@ -215,12 +221,12 @@ bool InstallWindow::Step4Finished()
 {
     ui->animationLabel->hide();
     _movie.stop();
-    disconnect(&_proc2, SIGNAL(finished(int)), this, SLOT(Step4Finished()));
+    disconnect(&_proc1, SIGNAL(finished(int)), this, SLOT(Step4Finished()));
 
-    if (_proc2.exitCode() != 0)
+    if (_proc1.exitCode() != 0)
     {
         return Failed(tr("Cannot unpack archive:<br />") +
-                      QString::fromLocal8Bit(_proc2.readAllStandardError()));
+                      QString::fromLocal8Bit(_proc1.readAllStandardError()));
     }
 
     PrintOK();
@@ -286,8 +292,8 @@ bool InstallWindow::Step2JsonCheck()
     _movie.start();
 
     _proc1.setStandardOutputProcess(&_proc2);
-    _proc1.start("ar p \"" + _game->IPKPath() + "\" data.tar.gz");
-    _proc2.start(TAR_APP" xz --wildcards \"*appinfo.json\" -O");
+    _proc1.start("/usr/bin/dpkg-deb --fsys-tarfile \"" + _game->IPKPath() + "\"");
+    _proc2.start(TAR_APP" x --wildcards \"*appinfo.json\" -O");
     // TODO: find if we can wait until first bytes in output and
     // stop process
     connect(&_proc2, SIGNAL(finished(int)), this, SLOT(Step2Finished()));
