@@ -2,6 +2,8 @@
 #define SETTINGSWINDOW_H
 
 #include <QDialog>
+#include <QString>
+
 #ifdef Q_WS_MAEMO_5
     #include <QMaemo5ValueButton>
 #else
@@ -31,6 +33,7 @@ private slots:
 
 private:
     Ui::SettingsWindow *ui;
+    QString _origDataDir;
 
 #ifdef Q_WS_MAEMO_5
     QMaemo5ValueButton *downloadsDirButton;
