@@ -102,46 +102,50 @@ p, li { white-space: pre-wrap; }
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/findipkwindow.ui" line="78"/>
         <source>Open Game Website</source>
-        <translation>Открыть сайт игры</translation>
+        <translation type="obsolete">Открыть сайт игры</translation>
     </message>
     <message>
         <source>Find .IPK on Internet...</source>
         <translation type="obsolete">Найти .ipk в интернете...</translation>
     </message>
     <message>
-        <location filename="../src/ui/findipkwindow.ui" line="97"/>
+        <location filename="../src/ui/findipkwindow.ui" line="78"/>
         <source>Locate .IPK file in different folder...</source>
         <translation>Найти .ipk в другой папке...</translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="16"/>
         <source>You have to download original game file with name </source>
-        <translation>Вы должны скачать оригинальный файл с именем </translation>
+        <translation type="obsolete">Вы должны скачать оригинальный файл с именем </translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="18"/>
         <source> and save it into the/Downloads folder.</source>
-        <translation>и сохранить его в каталог /Downloads.</translation>
+        <translation type="obsolete">и сохранить его в каталог /Downloads.</translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="40"/>
         <source>If you&apos;re sure that you downloaded right .ipk file to MyDocs/Downloads directory, then click &quot;Done&quot;</source>
-        <translation>Если вы уверены, что скачали правильный файл в папку /Downloads, тогда нажмите &quot;Вернуться&quot;</translation>
+        <translation type="obsolete">Если вы уверены, что скачали правильный файл в папку /Downloads, тогда нажмите &quot;Вернуться&quot;</translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="43"/>
         <source>Done</source>
-        <translation>Вернуться</translation>
+        <translation type="obsolete">Вернуться</translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="50"/>
+        <source>Manager can&apos;t find file &lt;b&gt;%1&lt;/b&gt; in &lt;b&gt;MyDocs/Downloads&lt;/b&gt; folder. Download it into this folder or locate in the different folder.&lt;br /&gt;&lt;br /&gt;&lt;font color=&quot;red&quot;&gt;Note, that there is &lt;b&gt;NO OFFICIAL WAY&lt;/b&gt; to buy .ipk files. The only possible way is to search google and download it by yourself.&lt;/font&gt;</source>
+        <translation type="obsolete">Менеджер не может найти файл &lt;b&gt;%1&lt;/b&gt; в каталоге  &lt;b&gt;MyDocs/Downloads&lt;/b&gt;. Скачайте его в этот каталог или найдите в другом каталоге. &lt;br /&gt;&lt;br /&gt;&lt;font color=&quot;red&quot;&gt;Обратите внимание, на данный момент &lt;b&gt;НЕТУ ОФИЦИАЛЬНОГО СПОСОБА&lt;/b&gt; купить .ipk игры. Единственная возможность - искать в гугле и скачивать самостоятельно.&lt;/font&gt;</translation>
+    </message>
+    <message>
+        <location filename="../src/findipkwindow.cpp" line="13"/>
+        <source>Manager can&apos;t find file &lt;b&gt;%1&lt;/b&gt; in &lt;b&gt;MyDocs/Downloads&lt;/b&gt; folder. Download it into this folder or locate in the different folder.&lt;br /&gt;&lt;font color=&quot;red&quot;&gt;Note, that there is &lt;b&gt;NO OFFICIAL WAY&lt;/b&gt; to buy PalmPre games. The only possible way is to search google and download it by yourself.&lt;/font&gt;</source>
+        <translation>Менеджер не может найти файл &lt;b&gt;%1&lt;/b&gt; в каталоге  &lt;b&gt;MyDocs/Downloads&lt;/b&gt;. Скачайте его в этот каталог или найдите в другом каталоге. &lt;br /&gt;&lt;font color=&quot;red&quot;&gt;Обратите внимание, на данный момент &lt;b&gt;НЕТ ОФИЦИАЛЬНОГО СПОСОБА&lt;/b&gt; купить PalmPre игры. Единственная возможность - искать в интернете и скачивать самостоятельно.&lt;/font&gt;</translation>
+    </message>
+    <message>
+        <location filename="../src/findipkwindow.cpp" line="30"/>
         <source>Locate IPK File</source>
         <translation>Найти .ipk файл</translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="52"/>
+        <location filename="../src/findipkwindow.cpp" line="32"/>
         <source>IPK (*.ipk)</source>
         <translation></translation>
     </message>
@@ -215,58 +219,58 @@ p, li { white-space: pre-wrap; }
         <translation>Распаковка архива (может занять немного времени)</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="222"/>
+        <location filename="../src/installwindow.cpp" line="228"/>
         <source>Cannot unpack archive:&lt;br /&gt;</source>
         <translation>Невозможно распаковать архив:&lt;br /&gt;</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="237"/>
+        <location filename="../src/installwindow.cpp" line="243"/>
         <source>Prepare directories</source>
         <translation>Подготовка каталогов</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="245"/>
+        <location filename="../src/installwindow.cpp" line="251"/>
         <source>Main property not found in Json: </source>
         <translation>Поле Main не найдено в appinfo.json: </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="266"/>
-        <location filename="../src/installwindow.cpp" line="270"/>
+        <location filename="../src/installwindow.cpp" line="272"/>
+        <location filename="../src/installwindow.cpp" line="276"/>
         <source>Can&apos;t create directory %1</source>
         <translation>Не могу создать каталог %1</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="284"/>
+        <location filename="../src/installwindow.cpp" line="290"/>
         <source>Extracting game info</source>
         <translation>Извлечение информации об игре</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="304"/>
+        <location filename="../src/installwindow.cpp" line="310"/>
         <source>Cannot parse JSON: </source>
         <translation>Ошибка разбора JSON: </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="311"/>
+        <location filename="../src/installwindow.cpp" line="317"/>
         <source>Error parsing appinfo.json!</source>
         <translation>Ошибка парсера JSON!</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="316"/>
+        <location filename="../src/installwindow.cpp" line="322"/>
         <source>Seems to be wrong game or naming error!&lt;br /&gt;Ipk ID: %1&lt;br /&gt;Expected ID mask: %2</source>
         <translation>Ошибка в соответствии игры имени!&lt;br /&gt;ID из файла: %1&lt;br /&gt;Ожидаемая маска ID: %2</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="323"/>
+        <location filename="../src/installwindow.cpp" line="329"/>
         <source> by </source>
         <translation> от </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="336"/>
+        <location filename="../src/installwindow.cpp" line="342"/>
         <source>Checking available space</source>
         <translation>Проверка свободного места</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="347"/>
+        <location filename="../src/installwindow.cpp" line="353"/>
         <source>Available free space in /home/user/MyDocs directory is %1MB, but the game requires %2MB!</source>
         <translation>Доступное место в MyDocs каталоге - %1МБ, но игре нужно %2МБ!</translation>
     </message>
@@ -278,17 +282,17 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">%1 игр доступно, %2 игр установлено</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="41"/>
+        <location filename="../src/mainwindow.cpp" line="43"/>
         <source>Install</source>
         <translation>Установка</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="42"/>
+        <location filename="../src/mainwindow.cpp" line="44"/>
         <source>Saves</source>
         <translation>Сейвы</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/mainwindow.cpp" line="89"/>
+        <location filename="../src/mainwindow.cpp" line="104"/>
         <source>%n games supported</source>
         <translation>
             <numerusform>%n игра поддерживается</numerusform>
@@ -297,7 +301,7 @@ p, li { white-space: pre-wrap; }
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/mainwindow.cpp" line="90"/>
+        <location filename="../src/mainwindow.cpp" line="105"/>
         <source>, %n games installed</source>
         <translation>
             <numerusform>, %n игра установлена</numerusform>
@@ -336,7 +340,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="../src/ui/mainwindow.ui" line="172"/>
-        <location filename="../src/mainwindow.cpp" line="29"/>
+        <location filename="../src/mainwindow.cpp" line="31"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
@@ -355,8 +359,8 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="../src/ui/managewindow.ui" line="239"/>
-        <location filename="../src/managewindow.cpp" line="162"/>
-        <location filename="../src/managewindow.cpp" line="198"/>
+        <location filename="../src/managewindow.cpp" line="169"/>
+        <location filename="../src/managewindow.cpp" line="207"/>
         <source>Install</source>
         <translation>Установить</translation>
     </message>
@@ -376,59 +380,59 @@ p, li { white-space: pre-wrap; }
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="110"/>
+        <location filename="../src/managewindow.cpp" line="117"/>
         <source>Space Required</source>
         <translation>Требует места</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="112"/>
+        <location filename="../src/managewindow.cpp" line="119"/>
         <source>MB</source>
         <translation>МБ</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="154"/>
-        <location filename="../src/managewindow.cpp" line="199"/>
+        <location filename="../src/managewindow.cpp" line="161"/>
+        <location filename="../src/managewindow.cpp" line="208"/>
         <source>Find IPK file...</source>
         <translation>Найти .IPK файл...</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="166"/>
-        <location filename="../src/managewindow.cpp" line="176"/>
+        <location filename="../src/managewindow.cpp" line="173"/>
+        <location filename="../src/managewindow.cpp" line="185"/>
         <source>Uninstall</source>
         <translation>Удалить</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="179"/>
+        <location filename="../src/managewindow.cpp" line="188"/>
         <source>Game installed</source>
         <translation>Игра установлена</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="181"/>
+        <location filename="../src/managewindow.cpp" line="190"/>
         <source> (version %1)</source>
         <translation> (версия %1)</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="196"/>
+        <location filename="../src/managewindow.cpp" line="205"/>
         <source>IPK file</source>
         <translation>IPK файл</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="201"/>
+        <location filename="../src/managewindow.cpp" line="210"/>
         <source>Found!</source>
         <translation>Найден!</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="204"/>
+        <location filename="../src/managewindow.cpp" line="213"/>
         <source>Not Found</source>
         <translation>Не найден</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="221"/>
+        <location filename="../src/managewindow.cpp" line="230"/>
         <source>Uninstall game?</source>
         <translation>Удалить игру?</translation>
     </message>
     <message>
-        <location filename="../src/managewindow.cpp" line="222"/>
+        <location filename="../src/managewindow.cpp" line="231"/>
         <source>Are you sure you want to uninstall %1?&lt;br /&gt;You might want to backup your saves first.</source>
         <translation>Вы уверены, что хотите удалить игру %1?&lt;br /&gt;Возможно вы хотите сначала сохранить сейвы.</translation>
     </message>
@@ -552,46 +556,59 @@ p, li { white-space: pre-wrap; }
         <translation>По умолчанию</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="59"/>
+        <location filename="../src/settingswindow.cpp" line="60"/>
         <source>Downloads Dir</source>
         <translation>Каталог с .ipk файлами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="60"/>
+        <location filename="../src/settingswindow.cpp" line="61"/>
         <source>Data Dir</source>
         <translation>Каталог с файлами данных</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="61"/>
+        <location filename="../src/settingswindow.cpp" line="62"/>
         <source>Bin Dir</source>
         <translation>Каталог с бинарными файлами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="62"/>
+        <location filename="../src/settingswindow.cpp" line="63"/>
         <source>Saves Dir</source>
         <translation>Каталог сэйвов</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="152"/>
+        <location filename="../src/settingswindow.cpp" line="162"/>
         <source>Downloads Directory</source>
         <translation>Каталог с .ipk файлами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="165"/>
+        <location filename="../src/settingswindow.cpp" line="175"/>
         <source>Saves Directory</source>
         <translation>Каталог с сэйвами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="177"/>
+        <location filename="../src/settingswindow.cpp" line="187"/>
         <source>Binary Directory</source>
         <translation>Каталог с бинарными файлами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="189"/>
+        <location filename="../src/settingswindow.cpp" line="199"/>
         <source>Game Data Directory</source>
         <translation>Каталог с файлами данных игр</translation>
     </message>
 </context>
+<context>
+    <name>TrackerCfg</name>
+    <message>
+        <location filename="../src/trackercfg.cpp" line="70"/>
+        <source>Tracker Config</source>
+        <translation>Настройки трекера медиафайлов</translation>
+    </message>
+    <message>
+        <location filename="../src/trackercfg.cpp" line="71"/>
+        <source>The tracker configuration must be changed to avoid messing up media cache with media from the games&apos; folders.&lt;br /&gt;The tracker also need to restart and rebuild databases.&lt;br /&gt;&lt;br /&gt;Do you want to change config and restart tracker now?</source>
+        <translation>Настройки кэша медиафайлов нужно изменить, чтобы видео и картинки из игр не попадали в общие плейлисты.&lt;br /&gt;Также нужен перезапуск трекера и обновление его баз.&lt;br /&gt;&lt;br /&gt;Вы хотите изменить настройки и перезапустить трекер сейчас?</translation>
+    </message>
+</context>
 <context>
     <name>UninstallWindow</name>
     <message>
