@@ -72,11 +72,11 @@
     <name>FindIpkWindow</name>
     <message>
         <source>Done</source>
-        <translation>完成</translation>
+        <translation type="obsolete">完成</translation>
     </message>
     <message>
         <source>You have to download original game file with name </source>
-        <translation>需要下载原本游戏文件 </translation>
+        <translation type="obsolete">需要下载原本游戏文件 </translation>
     </message>
     <message>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
@@ -92,11 +92,11 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>If you&apos;re sure that you downloaded right .ipk file to MyDocs/Downloads directory, then click &quot;Done&quot;</source>
-        <translation>确定下载正确的 .IPK文件到 MyDocs/Download 目录, 然后点击&quot;完成&quot;</translation>
+        <translation type="obsolete">确定下载正确的 .IPK文件到 MyDocs/Download 目录, 然后点击&quot;完成&quot;</translation>
     </message>
     <message>
         <source>Open Game Website</source>
-        <translation>打开游戏主页</translation>
+        <translation type="obsolete">打开游戏主页</translation>
     </message>
     <message>
         <source>IPK (*.ipk)</source>
@@ -112,7 +112,11 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source> and save it into the/Downloads folder.</source>
-        <translation>并且保存到 /Downloads 文件夹.</translation>
+        <translation type="obsolete">并且保存到 /Downloads 文件夹.</translation>
+    </message>
+    <message>
+        <source>Manager can&apos;t find file &lt;b&gt;%1&lt;/b&gt; in &lt;b&gt;MyDocs/Downloads&lt;/b&gt; folder. Download it into this folder or locate in the different folder.&lt;br /&gt;&lt;font color=&quot;red&quot;&gt;Note, that there is &lt;b&gt;NO OFFICIAL WAY&lt;/b&gt; to buy PalmPre games. The only possible way is to search google and download it by yourself.&lt;/font&gt;</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -457,6 +461,17 @@ p, li { white-space: pre-wrap; }
         <translation>游戏数据目录</translation>
     </message>
 </context>
+<context>
+    <name>TrackerCfg</name>
+    <message>
+        <source>Tracker Config</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The tracker configuration must be changed to avoid messing up media cache with media from the games&apos; folders.&lt;br /&gt;The tracker also need to restart and rebuild databases.&lt;br /&gt;&lt;br /&gt;Do you want to change config and restart tracker now?</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>UninstallWindow</name>
     <message>
